#define MFBPOLYGLYPHBLT xf1bppPolyGlyphBltInvert
#define OPEQ ^=
#include "../../../../mfb/mfbplygblt.c"
